@@ -3,10 +3,12 @@ import argparse
 from pdm.cli import actions
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.options import (
-    deprecated,
+    dry_run_option,
     install_group,
     packages_group,
+    prerelease_option,
     save_strategy_group,
+    unconstrained_option,
     update_strategy_group,
 )
 from pdm.exceptions import PdmUsageError
@@ -16,6 +18,16 @@ from pdm.project import Project
 class Command(BaseCommand):
     """Add package(s) to pyproject.toml and install them"""
 
+    arguments = BaseCommand.arguments + [
+        save_strategy_group,
+        update_strategy_group,
+        prerelease_option,
+        unconstrained_option,
+        packages_group,
+        install_group,
+        dry_run_option,
+    ]
+
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
         parser.add_argument(
             "-d",
@@ -24,26 +36,9 @@ class Command(BaseCommand):
             action="store_true",
             help="Add packages into dev dependencies",
         )
-        parser.add_argument(
-            "-s",
-            "--section",
-            dest="group",
-            help="(DEPRECATED) Alias of `-G/--group`",
-            type=deprecated(
-                "`-s/--section` is deprecated in favor of `-G/--groups` "
-                "and will be removed in the next minor release."
-            ),
-        )
         parser.add_argument(
             "-G", "--group", help="Specify the target dependency group to add into"
         )
-        parser.add_argument(
-            "-u",
-            "--unconstrained",
-            action="store_true",
-            default=False,
-            help="Ignore the version constraint of pinned packages",
-        )
         parser.add_argument(
             "--no-sync",
             dest="sync",
@@ -51,10 +46,6 @@ class Command(BaseCommand):
             action="store_false",
             help="Only write pyproject.toml and do not sync the working set",
         )
-        save_strategy_group.add_to_parser(parser)
-        update_strategy_group.add_to_parser(parser)
-        packages_group.add_to_parser(parser)
-        install_group.add_to_parser(parser)
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
         if options.editables and options.no_editable:
@@ -71,4 +62,6 @@ class Command(BaseCommand):
             unconstrained=options.unconstrained,
             no_editable=options.no_editable,
             no_self=options.no_self,
+            dry_run=options.dry_run,
+            prerelease=options.prerelease,
         )
