@@ -5,7 +5,7 @@ import click
 
 from pdm.cli import actions
 from pdm.cli.commands.base import BaseCommand
-from pdm.cli.options import groups_group, install_group
+from pdm.cli.options import dry_run_option, groups_group, install_group
 from pdm.project import Project
 
 
@@ -15,32 +15,35 @@ class Command(BaseCommand):
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
         groups_group.add_to_parser(parser)
         install_group.add_to_parser(parser)
+        dry_run_option.add_to_parser(parser)
         parser.add_argument(
             "--no-lock",
             dest="lock",
             action="store_false",
             default=True,
-            help="Don't do lock if lockfile is not found or outdated.",
+            help="Don't do lock if the lock file is not found or outdated",
+        )
+        parser.add_argument(
+            "--check",
+            action="store_true",
+            help="Check if the lock file is up to date and fail otherwise",
         )
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
         if not project.meta and click._compat.isatty(sys.stdout):
             actions.ask_for_import(project)
 
-        if options.lock:
-            if not (
-                project.lockfile_file.exists() and project.is_lockfile_compatible()
-            ):
+        strategy = actions.check_lockfile(project, False)
+        if strategy:
+            if options.check:
                 project.core.ui.echo(
-                    "Lock file does not exist or is incompatible, "
-                    "trying to generate one..."
+                    "Please run `pdm lock` to update the lock file", err=True
                 )
-                actions.do_lock(project, strategy="all")
-            elif not project.is_lockfile_hash_match():
-                project.core.ui.echo(
-                    "Lock file hash doesn't match pyproject.toml, regenerating..."
-                )
-                actions.do_lock(project, strategy="reuse")
+                sys.exit(1)
+            if options.lock:
+                project.core.ui.echo("Updating the lock file...", fg="green", err=True)
+                actions.do_lock(project, strategy=strategy, dry_run=options.dry_run)
+
         actions.do_sync(
             project,
             groups=options.groups,
@@ -48,4 +51,5 @@ class Command(BaseCommand):
             default=options.default,
             no_editable=options.no_editable,
             no_self=options.no_self,
+            dry_run=options.dry_run,
         )
