@@ -10,9 +10,9 @@ from json import dumps
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, Iterable, Mapping, MutableMapping, cast
 
-import atoml
+import tomlkit
 from packaging.specifiers import SpecifierSet
-from pip._vendor.pkg_resources import parse_version
+from packaging.version import parse as parse_version
 from resolvelib.structs import DirectedGraph
 
 from pdm import termui
@@ -30,6 +30,7 @@ from pdm.models.requirements import (
 from pdm.models.specifiers import get_specifier
 from pdm.models.working_set import WorkingSet
 from pdm.project import Project
+from pdm.utils import is_path_relative_to
 
 if TYPE_CHECKING:
     from resolvelib.resolvers import RequirementInformation, ResolutionImpossible
@@ -431,12 +432,12 @@ def format_lockfile(
     """Format lock file from a dict of resolved candidates, a mapping of dependencies
     and a collection of package summaries.
     """
-    packages = atoml.aot()
-    file_hashes = atoml.table()
+    packages = tomlkit.aot()
+    file_hashes = tomlkit.table()
     for k, v in sorted(mapping.items()):
-        base = atoml.table()
+        base = tomlkit.table()
         base.update(v.as_lockfile_entry())  # type: ignore
-        base.add("summary", v.summary)
+        base.add("summary", v.summary or "")
         deps = make_array(sorted(r.as_line() for r in fetched_dependencies[k]), True)
         if len(deps) > 0:
             base.add("dependencies", deps)
@@ -445,15 +446,15 @@ def format_lockfile(
             key = f"{strip_extras(k)[0]} {v.version}"
             if key in file_hashes:
                 continue
-            array = atoml.array().multiline(True)
+            array = tomlkit.array().multiline(True)
             for filename, hash_value in v.hashes.items():
                 inline = make_inline_table({"file": filename, "hash": hash_value})
                 array.append(inline)  # type: ignore
             if array:
                 file_hashes.add(key, array)
-    doc = atoml.document()
+    doc = tomlkit.document()
     doc.add("package", packages)  # type: ignore
-    metadata = atoml.table()
+    metadata = tomlkit.table()
     metadata.add("files", file_hashes)
     doc.add("metadata", metadata)  # type: ignore
     return cast(dict, doc)
@@ -482,6 +483,8 @@ def save_version_specifiers(
                         r.specifier = get_specifier(f">={version},<{parsed.major + 1}")
                     else:
                         r.specifier = get_specifier(f"~={parsed.major}.{parsed.minor}")
+                elif save_strategy == "minimum":
+                    r.specifier = get_specifier(f">={resolved[name].version}")
 
 
 def check_project_file(project: Project) -> None:
@@ -531,18 +534,55 @@ def set_env_in_reg(env_name: str, value: str) -> None:
 
 
 def format_resolution_impossible(err: ResolutionImpossible) -> str:
-    causes: list[RequirementInformation] = err.causes
-    result = ["Unable to find a resolution that satisfies the following requirements:"]
+    from pdm.resolver.python import PythonRequirement
 
-    for req, parent in causes:
+    causes: list[RequirementInformation] = err.causes
+    info_lines: set[str] = set()
+    if all(isinstance(cause.requirement, PythonRequirement) for cause in causes):
+        project_requires = next(
+            (cause.requirement for cause in causes if cause.parent is None)
+        )
+        conflicting = [
+            cause
+            for cause in causes
+            if cause.parent is not None
+            and not cause.requirement.specifier.is_superset(project_requires.specifier)
+        ]
+        result = [
+            "Unable to find a resolution because the following dependencies don't work "
+            "on all Python versions defined by the project's `requires-python`: "
+            f"{termui.green(str(project_requires.specifier))}"
+        ]
+        for req, parent in conflicting:
+            info_lines.add(f"  {req.as_line()} (from {repr(parent)})")
+        result.extend(sorted(info_lines))
         result.append(
-            f"  {req.as_line()} (from {repr(parent) if parent else 'project'})"
+            "To fix this, you can change the value of `requires-python` "
+            "in pyproject.toml."
+        )
+        return "\n".join(result)
+
+    if len(causes) == 1:
+        return (
+            "Unable to find a resolution for "
+            f"{termui.green(causes[0].requirement.identify())}\n"
+            "Please make sure the package name is correct."
         )
 
+    result = [
+        f"Unable to find a resolution for "
+        f"{termui.green(causes[0].requirement.identify())} because of the following "
+        "conflicts:"
+    ]
+    for req, parent in causes:
+        info_lines.add(
+            f"  {req.as_line()} (from {repr(parent) if parent else 'project'})"
+        )
+    result.extend(sorted(info_lines))
     result.append(
-        "Please make sure the package names are correct. If so, you can either "
-        "loosen the version constraints of these dependencies, or "
-        "set a narrower `requires-python` range in the pyproject.toml."
+        "To fix this, you could loosen the dependency version constraints in "
+        "pyproject.toml. See https://pdm.fming.dev/usage/dependency"
+        "/#solve-the-locking-failure for more details."
     )
     return "\n".join(result)
 
@@ -591,21 +631,9 @@ def merge_dictionary(
         elif isinstance(value, dict):
             target[key].update(value)
         elif isinstance(value, list):
-            target[key].extend(atoml.item(v) for v in value)
-
-
-def frozen_requirement_from_dist(dist: Distribution) -> str:
-    """Get the requirement line from a distribution"""
-    from pip._vendor.pkg_resources import distributions_from_metadata
-
-    from pdm.models.pip_shims import FrozenRequirement
-
-    dist_path = str(dist._path)  # type: ignore
-    try:
-        pkg_dist = next(distributions_from_metadata(dist_path))
-    except StopIteration:
-        raise TypeError(f"Not a valid distribution metadata: {dist_path}")
-    return str(FrozenRequirement.from_dist(pkg_dist))
+            target[key].extend(value)
+        else:
+            target[key] = value
 
 
 def is_pipx_installation() -> bool:
@@ -617,13 +645,9 @@ def is_homebrew_installation() -> bool:
 
 
 def is_scoop_installation() -> bool:
-    if os.name != "nt":
-        return False
-    try:
-        Path(sys.prefix).relative_to(Path.home() / "scoop/apps/pdm")
-    except ValueError:
-        return False
-    return True
+    return os.name == "nt" and is_path_relative_to(
+        sys.prefix, Path.home() / "scoop/apps/pdm"
+    )
 
 
 def get_dist_location(dist: Distribution) -> str:
