@@ -80,7 +80,7 @@ def parse_requirement_file(
 def check_fingerprint(project: Project, filename: PathLike) -> bool:
     import tomli
 
-    with open(filename, encoding="utf-8") as fp:
+    with open(filename, "rb") as fp:
         try:
             tomli.load(fp)
         except ValueError:
@@ -107,9 +107,9 @@ def convert(
     data: dict[str, Any] = {}
     settings: dict[str, Any] = {}
     if options.dev:
-        settings["dev-dependencies"] = {options.section or "dev": deps}
-    elif options.section:
-        data["optional-dependencies"] = {options.section: deps}
+        settings["dev-dependencies"] = {options.group or "dev": deps}
+    elif options.group:
+        data["optional-dependencies"] = {options.group: deps}
     else:
         data["dependencies"] = deps
     if finder.index_urls:
@@ -128,7 +128,9 @@ def export(
     lines = []
     for candidate in sorted(candidates, key=lambda x: x.identify()):
         if isinstance(candidate, Candidate):
-            req = dataclasses.replace(candidate.req, specifier=f"=={candidate.version}")
+            req = dataclasses.replace(
+                candidate.req, specifier=f"=={candidate.version}", marker=None
+            )
         else:
             assert isinstance(candidate, Requirement)
             req = candidate
