@@ -3,8 +3,7 @@ from __future__ import annotations
 import functools
 import multiprocessing
 import traceback
-from concurrent.futures._base import Future
-from concurrent.futures.thread import ThreadPoolExecutor
+from concurrent.futures import Future, ThreadPoolExecutor
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from pdm import termui
@@ -13,8 +12,8 @@ from pdm.exceptions import InstallationError
 from pdm.installers.manager import InstallManager
 from pdm.models.candidates import Candidate
 from pdm.models.environment import Environment
-from pdm.models.requirements import strip_extras
-from pdm.utils import is_egg_link
+from pdm.models.requirements import parse_requirement, strip_extras
+from pdm.utils import is_editable
 
 
 class DummyFuture:
@@ -41,7 +40,7 @@ class DummyFuture:
 
 
 class DummyExecutor:
-    """A synchronous pool class to mimick ProcessPoolExecuter's interface.
+    """A synchronous pool class to mimic ProcessPoolExecuter's interface.
     functions are called and awaited for the result
     """
 
@@ -60,6 +59,12 @@ class DummyExecutor:
         return
 
 
+def editables_candidate(environment: Environment) -> Candidate | None:
+    """Return a candidate for `editables` package"""
+    repository = environment.project.get_repository()
+    return next(iter(repository.find_candidates(parse_requirement("editables"))), None)
+
+
 class Synchronizer:
     """Synchronize the working set with given installation candidates"""
 
@@ -75,6 +80,7 @@ class Synchronizer:
         install_self: bool = False,
         no_editable: bool = False,
         use_install_cache: bool = False,
+        reinstall: bool = False,
     ) -> None:
         self.environment = environment
         self.clean = clean
@@ -83,6 +89,7 @@ class Synchronizer:
         self.no_editable = no_editable
         self.install_self = install_self
         self.use_install_cache = use_install_cache
+        self.reinstall = reinstall
 
         self.parallel = environment.project.config["parallel_install"]
         locked_repository = environment.project.locked_repository
@@ -93,6 +100,16 @@ class Synchronizer:
         if self.no_editable:
             for candidate in candidates.values():
                 candidate.req.editable = None  # type: ignore
+        elif (
+            self.install_self
+            and getattr(self.environment.project.meta, "editable_backend", "editables")
+            == "editables"
+            and "editables" not in candidates
+        ):
+            # Install `editables` as well as required by self project
+            editables = editables_candidate(environment)
+            if editables is not None:
+                candidates["editables"] = editables
         self.candidates = candidates
         self._manager: InstallManager | None = None
 
@@ -135,7 +152,8 @@ class Synchronizer:
                 can = candidates.pop(key)
                 if (
                     can.req.editable
-                    or is_egg_link(dist)
+                    or self.reinstall
+                    or is_editable(dist)
                     or (dist.version != can.version)
                 ):
                     to_update.append(key)
