@@ -16,8 +16,8 @@ from typing import (
     TypeVar,
 )
 
+from packaging.version import parse as parse_version
 from pip._vendor.html5lib import parse
-from pkg_resources import parse_version
 
 from pdm import termui
 from pdm._types import CandidateInfo, Package, SearchResult, Source
@@ -120,9 +120,16 @@ class BaseRepository:
             if requirement.specifier.contains(  # type: ignore
                 c.version, allow_prereleases  # type: ignore
             )
-            and requires_python.is_subset(c.requires_python)
         ]
 
+        applicable_cans_python_compatible = [
+            c for c in applicable_cans if requires_python.is_subset(c.requires_python)
+        ]
+        # Evaluate data-requires-python attr and discard incompatible candidates
+        # to reduce the number of candidates to resolve.
+        if applicable_cans_python_compatible:
+            applicable_cans = applicable_cans_python_compatible
+
         if not applicable_cans:
             termui.logger.debug("\tCould not find any matching candidates.")
 
@@ -132,8 +139,14 @@ class BaseRepository:
                 c
                 for c in cans
                 if requirement.specifier.contains(c.version, True)  # type: ignore
-                and requires_python.is_subset(c.requires_python)
             ]
+            applicable_cans_python_compatible = [
+                c
+                for c in applicable_cans
+                if requires_python.is_subset(c.requires_python)
+            ]
+            if applicable_cans_python_compatible:
+                applicable_cans = applicable_cans_python_compatible
 
             if not applicable_cans:
                 termui.logger.debug(
@@ -206,7 +219,8 @@ class BaseRepository:
             return {
                 c.link.filename: self._hash_cache.get_hash(c.link)  # type: ignore
                 for c in matching_candidates
-            }
+                if c.link and not c.link.is_vcs
+            } or None
 
     def dependency_generators(self) -> Iterable[Callable[[Candidate], CandidateInfo]]:
         """Return an iterable of getter functions to get dependencies, which will be
@@ -281,7 +295,7 @@ class PyPIRepository(BaseRepository):
         if not cans:
             raise CandidateNotFound(
                 f"Unable to find candidates for {requirement.project_name}. There may "
-                "exist some issues with the package index or network condition."
+                "exist some issues with the package name or network condition."
             )
         return cans
 
