@@ -1,11 +1,17 @@
+from __future__ import annotations
+
+import json
 from functools import lru_cache
-from typing import Iterable, List, Set, Tuple, Union, cast
+from pathlib import Path
+from typing import Any, Iterable, List, Set, Tuple, Union, cast
 
 from pip._vendor.packaging.specifiers import SpecifierSet
 
 from pdm.exceptions import InvalidPyVersion
 from pdm.models.versions import Version
 
+MAX_VERSIONS_FILE = Path(__file__).with_name("python_max_versions.json")
+
 
 @lru_cache()
 def get_specifier(version_str: Union[SpecifierSet, str]) -> SpecifierSet:
@@ -44,29 +50,11 @@ def _normalize_op_specifier(op: str, version_str: str) -> Tuple[str, Version]:
 class PySpecSet(SpecifierSet):
     """A custom SpecifierSet that supports merging with logic operators (&, |)."""
 
-    # TODO: fetch from python.org and cache
     PY_MAX_MINOR_VERSION = {
-        Version("2"): 7,
-        Version("2.0"): 1,
-        Version("2.1"): 3,
-        Version("2.2"): 3,
-        Version("2.3"): 7,
-        Version("2.4"): 6,
-        Version("2.5"): 6,
-        Version("2.6"): 9,
-        Version("2.7"): 18,
-        Version("3.0"): 1,
-        Version("3.1"): 5,
-        Version("3.2"): 6,
-        Version("3.3"): 7,
-        Version("3.4"): 10,
-        Version("3.5"): 10,
-        Version("3.6"): 13,
-        Version("3.7"): 10,
-        Version("3.8"): 8,
-        Version("3.9"): 2,
+        Version(key): value
+        for key, value in json.loads(MAX_VERSIONS_FILE.read_text()).items()
     }
-    MAX_MAJOR_VERSION = Version("4")
+    MAX_MAJOR_VERSION = max(PY_MAX_MINOR_VERSION)[:1].bump()
 
     def __init__(self, version_str: str = "", analyze: bool = True) -> None:
         if version_str == "*":
@@ -93,19 +81,13 @@ class PySpecSet(SpecifierSet):
             if op == "!=":
                 excludes.add(version)
             elif op[0] == ">":
-                if op == ">=":
-                    new_lower = version
-                else:
-                    new_lower = version.bump()
-                if new_lower > lower_bound:
-                    lower_bound = new_lower
+                lower_bound = max(
+                    lower_bound, version if op == ">=" else version.bump()
+                )
             elif op[0] == "<":
-                if op == "<=":
-                    new_upper = version.bump()
-                else:
-                    new_upper = version
-                if new_upper < upper_bound:
-                    upper_bound = new_upper
+                upper_bound = min(
+                    upper_bound, version.bump() if op == "<=" else version
+                )
             elif op == "~=":
                 new_lower = version.complete()
                 new_upper = version.bump(-2)
@@ -125,9 +107,9 @@ class PySpecSet(SpecifierSet):
         excludes: Iterable[Version],
     ) -> Tuple[Version, Version, List[Version]]:
         sorted_excludes = sorted(excludes)
-        wildcard_excludes = set(
+        wildcard_excludes = {
             version[:-1] for version in sorted_excludes if version.is_wildcard
-        )
+        }
         # Remove versions that are already excluded by another wildcard exclude.
         sorted_excludes = [
             version
@@ -172,20 +154,19 @@ class PySpecSet(SpecifierSet):
                 sorted_excludes.remove(version)
                 continue
 
-            if version.is_wildcard:
-                valid_length = len(version._version) - 1
-                valid_version = version[:valid_length]
+            if not version.is_wildcard:
+                break
+            valid_length = len(version._version) - 1
+            valid_version = version[:valid_length]
 
-                if upper.startswith(valid_version) or version.bump(-2) == upper:
-                    # Case 1: The upper bound is excluded, e.g: <3.7.3,!=3.7.*
-                    # set the upper to the zero version: <3.7.0
-                    # Case 2: The upper bound is adjacent to the excluded one,
-                    # e.g: <3.7.0,!=3.6.*
-                    # Move the upper bound to below the excluded: <3.6.0
-                    upper = valid_version.complete()
-                    sorted_excludes.remove(version)
-                else:
-                    break
+            if upper.startswith(valid_version) or version.bump(-2) == upper:
+                # Case 1: The upper bound is excluded, e.g: <3.7.3,!=3.7.*
+                # set the upper to the zero version: <3.7.0
+                # Case 2: The upper bound is adjacent to the excluded one,
+                # e.g: <3.7.0,!=3.6.*
+                # Move the upper bound to below the excluded: <3.6.0
+                upper = valid_version.complete()
+                sorted_excludes.remove(version)
             else:
                 break
 
@@ -203,13 +184,13 @@ class PySpecSet(SpecifierSet):
         if not self.is_impossible:
             super().__init__(str(self))
 
-    def _comp_key(self):
+    def _comp_key(self) -> Tuple[Version, Version, Tuple[Version, ...]]:
         return (self._lower_bound, self._upper_bound, tuple(self._excludes))
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash(self._comp_key())
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         if not isinstance(other, PySpecSet):
             return False
         return self._comp_key() == other._comp_key()
@@ -361,7 +342,7 @@ class PySpecSet(SpecifierSet):
         if other._upper_bound >= self.MAX_MAJOR_VERSION:
             # XXX: narrow down the upper bound to ``MAX_MAJOR_VERSION``
             # So that `>=3.6,<4.0` is considered a superset of `>=3.7`, see issues/66
-            other._upper_bound = self.MAX_MAJOR_VERSION.complete(0)
+            other._upper_bound = self.MAX_MAJOR_VERSION
         lower, upper, excludes = self._merge_bounds_and_excludes(
             other._lower_bound, other._upper_bound, self._excludes
         )
@@ -443,12 +424,12 @@ class ImpossiblePySpecSet(PySpecSet):
     A special subclass of PySpecSet that references to an impossible specifier set.
     """
 
-    def __init__(self, version_str="", analyze=True):
+    def __init__(self, version_str: str = "", analyze: bool = True) -> None:
         super().__init__(version_str=version_str, analyze=False)
         # Make sure the spec set is impossible
         self._lower_bound = Version.MAX
         self._upper_bound = Version.MIN
 
     @property
-    def is_impossible(self):
+    def is_impossible(self) -> bool:
         return True
