@@ -331,16 +331,6 @@ def cd(path: str | Path) -> Iterator:
         os.chdir(_old_cwd)
 
 
-@contextmanager
-def temp_environ() -> Iterator:
-    environ = os.environ.copy()
-    try:
-        yield
-    finally:
-        os.environ.clear()
-        os.environ.update(environ)
-
-
 @contextmanager
 def open_file(url: str, session: Session | None = None) -> Iterator[BinaryIO]:
     if url.startswith("file://"):
