@@ -25,6 +25,12 @@ def test_add_package(project, working_set, is_dev):
         assert package in working_set
 
 
+def test_add_command(project, invoke, mocker):
+    do_add = mocker.patch.object(actions, "do_add")
+    invoke(["add", "requests"], obj=project)
+    do_add.assert_called_once()
+
+
 @pytest.mark.usefixtures("repository")
 def test_add_package_to_custom_group(project, working_set):
     actions.do_add(project, group="test", packages=["requests"])
@@ -125,6 +131,12 @@ def test_add_package_save_wildcard(project):
     assert project.meta.dependencies[0] == "requests"
 
 
+@pytest.mark.usefixtures("repository")
+def test_add_package_save_minimum(project):
+    actions.do_add(project, sync=False, save="minimum", packages=["requests"])
+    assert project.meta.dependencies[0] == "requests>=2.19.1"
+
+
 def test_add_package_update_reuse(project, repository):
     actions.do_add(project, sync=False, save="wildcard", packages=["requests", "pytz"])
 
@@ -254,3 +266,10 @@ def test_add_with_dry_run(project, capsys):
     assert not project.get_dependencies()
     assert "requests 2.19.1" in out
     assert "urllib3 1.22" in out
+
+
+@pytest.mark.usefixtures("repository")
+def test_add_with_prerelease(project, working_set):
+    actions.do_add(project, packages=["urllib3"], prerelease=True)
+    assert working_set["urllib3"].version == "1.23b0"
+    assert project.meta.dependencies[0] == "urllib3<2,>=1.23b0"
