@@ -4,10 +4,11 @@ from pdm.utils import cd
 
 
 @pytest.mark.integration
+@pytest.mark.network
 @pytest.mark.parametrize("python_version", ["2.7", "3.6", "3.7", "3.8", "3.9"])
-def test_basic_integration(python_version, project_no_init, invoke):
+def test_basic_integration(python_version, core, tmp_path, invoke):
     """An e2e test case to ensure PDM works on all supported Python versions"""
-    project = project_no_init
+    project = core.create_project(tmp_path)
     project.root.joinpath("foo.py").write_text("import django\n")
     additional_args = ["--no-self"] if python_version == "2.7" else []
     invoke(["init"], input="\ny\n\n\n\n\n\n>=2.7\n", obj=project, strict=True)
@@ -25,9 +26,7 @@ def test_basic_integration(python_version, project_no_init, invoke):
     )
 
 
-@pytest.mark.integration
-def test_actual_list_freeze(project, invoke):
-    project.meta["requires-python"] = ">=3.6"
-    invoke(["add", "click==7.1.2"], obj=project, strict=True)
+def test_actual_list_freeze(project, local_finder, invoke):
+    invoke(["add", "first"], obj=project, strict=True)
     r = invoke(["list", "--freeze"], obj=project)
-    assert "click==7.1.2" in r.output
+    assert "first==2.0.2" in r.output
